@@ -74,7 +74,7 @@ const ApplicationMenuItem = new Lang.Class({
     },
 
     activate: function(event) {
-	this._app.open_new_window(event.get_time());
+	this._app.open_new_window(-1);
         this._button.selectCategory(null, null);
         this._button.menu.toggle();
 	this.parent(event);
@@ -287,18 +287,22 @@ const ApplicationsButton = new Lang.Class({
         this.actor.label_actor = this._label;
 
         this.actor.connect('captured-event', Lang.bind(this, this._onCapturedEvent));
+        this.actor.connect('destroy', Lang.bind(this, this._onDestroy));
 
-        _showingId = Main.overview.connect('showing', Lang.bind(this, function() {
+        this._showingId = Main.overview.connect('showing', Lang.bind(this, function() {
             this.actor.add_accessible_state (Atk.StateType.CHECKED);
         }));
-        _hidingId = Main.overview.connect('hiding', Lang.bind(this, function() {
+        this._hidingId = Main.overview.connect('hiding', Lang.bind(this, function() {
             this.actor.remove_accessible_state (Atk.StateType.CHECKED);
         }));
+        Main.layoutManager.connect('startup-complete',
+                                   Lang.bind(this, this._setKeybinding));
+        this._setKeybinding();
 
         this.reloadFlag = false;
         this._createLayout();
         this._display();
-        _installedChangedId = appSys.connect('installed-changed', Lang.bind(this, function() {
+        this._installedChangedId = appSys.connect('installed-changed', Lang.bind(this, function() {
             if (this.menu.isOpen) {
                 this._redisplay();
                 this.mainBox.show();
@@ -310,7 +314,7 @@ const ApplicationsButton = new Lang.Class({
         // Since the hot corner uses stage coordinates, Clutter won't
         // queue relayouts for us when the panel moves. Queue a relayout
         // when that happens.
-        _panelBoxChangedId = Main.layoutManager.connect('panel-box-changed', Lang.bind(this, function() {
+        this._panelBoxChangedId = Main.layoutManager.connect('panel-box-changed', Lang.bind(this, function() {
             container.queue_relayout();
         }));
     },
@@ -326,6 +330,20 @@ const ApplicationsButton = new Lang.Class({
         return separator;
     },
 
+    _onDestroy: function() {
+        Main.overview.disconnect(this._showingId);
+        Main.overview.disconnect(this._hidingId);
+        Main.layoutManager.disconnect(this._panelBoxChangedId);
+        appSys.disconnect(this._installedChangedId);
+
+        Main.wm.setCustomKeybindingHandler('panel-main-menu',
+                                           Shell.ActionMode.NORMAL |
+                                           Shell.ActionMode.OVERVIEW,
+                                           Main.sessionMode.hasOverview ?
+                                           Lang.bind(Main.overview, Main.overview.toggle) :
+                                           null);
+    },
+
     _onCapturedEvent: function(actor, event) {
         if (event.type() == Clutter.EventType.BUTTON_PRESS) {
             if (!Main.overview.shouldToggleByCornerOrButton())
@@ -371,6 +389,15 @@ const ApplicationsButton = new Lang.Class({
        this.parent(menu, open);
     },
 
+    _setKeybinding: function() {
+        Main.wm.setCustomKeybindingHandler('panel-main-menu',
+                                           Shell.ActionMode.NORMAL |
+                                           Shell.ActionMode.OVERVIEW,
+                                           Lang.bind(this, function() {
+                                               this.menu.toggle();
+                                           }));
+    },
+
     _redisplay: function() {
         this.applicationsBox.destroy_all_children();
         this.categoriesBox.destroy_all_children();
@@ -573,40 +600,18 @@ const ApplicationsButton = new Lang.Class({
 
 let appsMenuButton;
 let activitiesButton;
-let _hidingId;
-let _installedChangedId;
-let _panelBoxChangedId;
-let _showingId;
 
 function enable() {
     activitiesButton = Main.panel.statusArea['activities'];
     activitiesButton.container.hide();
     appsMenuButton = new ApplicationsButton();
     Main.panel.addToStatusArea('apps-menu', appsMenuButton, 1, 'left');
-
-    Main.wm.setCustomKeybindingHandler('panel-main-menu',
-                                       Shell.ActionMode.NORMAL |
-                                       Shell.ActionMode.OVERVIEW,
-                                       function() {
-                                           appsMenuButton.menu.toggle();
-                                       });
 }
 
 function disable() {
     Main.panel.menuManager.removeMenu(appsMenuButton.menu);
-    appSys.disconnect(_installedChangedId);
-    Main.layoutManager.disconnect(_panelBoxChangedId);
-    Main.overview.disconnect(_hidingId);
-    Main.overview.disconnect(_showingId);
     appsMenuButton.destroy();
     activitiesButton.container.show();
-
-    Main.wm.setCustomKeybindingHandler('panel-main-menu',
-                                       Shell.ActionMode.NORMAL |
-                                       Shell.ActionMode.OVERVIEW,
-                                       Main.sessionMode.hasOverview ?
-                                       Lang.bind(Main.overview, Main.overview.toggle) :
-                                       null);
 }
 
 function init(metadata) {
