@@ -647,7 +647,8 @@ const WorkspaceIndicator = new Lang.Class({
     Extends: PanelMenu.Button,
 
     _init: function(){
-        this.parent(0.0, _("Workspace Indicator"));
+        this.parent(0.0, _("Workspace Indicator"), true);
+        this.setMenu(new PopupMenu.PopupMenu(this.actor, 0.0, St.Side.BOTTOM));
         this.actor.add_style_class_name('window-list-workspace-indicator');
         this.menu.actor.remove_style_class_name('panel-menu');
 
